@@ -8,7 +8,7 @@
 
 from .utils import validate_variables, apply_model_changes, set_up_simulation, exec_xpp_simulation, get_results_of_sed_variables
 from biosimulators_utils.combine.exec import exec_sedml_docs_in_archive
-from biosimulators_utils.config import get_config
+from biosimulators_utils.config import get_config, Config  # noqa: F401
 from biosimulators_utils.log.data_model import CombineArchiveLog, TaskLog  # noqa: F401
 from biosimulators_utils.model_lang.xpp.validation import validate_model
 from biosimulators_utils.report.data_model import ReportFormat, SedDocumentResults  # noqa: F401
@@ -24,11 +24,7 @@ import functools
 __all__ = ['exec_sedml_docs_in_combine_archive', 'exec_sed_task']
 
 
-def exec_sedml_docs_in_combine_archive(archive_filename, out_dir,
-                                       return_results=False,
-                                       report_formats=None, plot_formats=None,
-                                       bundle_outputs=None, keep_individual_outputs=None,
-                                       raise_exceptions=True):
+def exec_sedml_docs_in_combine_archive(archive_filename, out_dir, config=None):
     """ Execute the SED tasks defined in a COMBINE/OMEX archive and save the outputs
 
     Args:
@@ -40,12 +36,7 @@ def exec_sedml_docs_in_combine_archive(archive_filename, out_dir,
             * HDF5: directory in which to save a single HDF5 file (``{ out_dir }/reports.h5``),
               with reports at keys ``{ relative-path-to-SED-ML-file-within-archive }/{ report.id }`` within the HDF5 file
 
-        return_results (:obj:`bool`, optional): whether to return the result of each output of each SED-ML file
-        report_formats (:obj:`list` of :obj:`ReportFormat`, optional): report format (e.g., csv or h5)
-        plot_formats (:obj:`list` of :obj:`VizFormat`, optional): report format (e.g., pdf)
-        bundle_outputs (:obj:`bool`, optional): if :obj:`True`, bundle outputs into archives for reports and plots
-        keep_individual_outputs (:obj:`bool`, optional): if :obj:`True`, keep individual output files
-        raise_exceptions (:obj:`bool`, optional): whether to raise exceptions
+        config (:obj:`Config`, optional): BioSimulators common configuration
 
     Returns:
         :obj:`tuple`:
@@ -56,21 +47,17 @@ def exec_sedml_docs_in_combine_archive(archive_filename, out_dir,
     sed_doc_executer = functools.partial(exec_sed_doc, exec_sed_task)
     return exec_sedml_docs_in_archive(sed_doc_executer, archive_filename, out_dir,
                                       apply_xml_model_changes=False,
-                                      return_results=return_results,
-                                      report_formats=report_formats,
-                                      plot_formats=plot_formats,
-                                      bundle_outputs=bundle_outputs,
-                                      keep_individual_outputs=keep_individual_outputs,
-                                      raise_exceptions=raise_exceptions)
+                                      config=config)
 
 
-def exec_sed_task(task, variables, log=None):
+def exec_sed_task(task, variables, log=None, config=None):
     """ Execute a task and save its results
 
     Args:
        task (:obj:`Task`): task
        variables (:obj:`list` of :obj:`Variable`): variables that should be recorded
        log (:obj:`TaskLog`, optional): log for the task
+       config (:obj:`Config`, optional): BioSimulators common configuration
 
     Returns:
         :obj:`tuple`:
@@ -84,9 +71,10 @@ def exec_sed_task(task, variables, log=None):
           * Task requires a time course that XPP doesn't support
           * Task requires an algorithm that XPP doesn't support
     """
-    config = get_config()
+    config = config or get_config()
 
-    log = log or TaskLog()
+    if config.LOG and not log:
+        log = TaskLog()
 
     # validate task
     model = task.model
@@ -121,7 +109,7 @@ def exec_sed_task(task, variables, log=None):
     apply_model_changes(xpp_sim, model.changes)
 
     # setup simulation
-    exec_kisao_id = set_up_simulation(sim, xpp_sim['simulation_method'])
+    exec_kisao_id = set_up_simulation(sim, xpp_sim['simulation_method'], config=config)
 
     # run simulation
     raw_results = exec_xpp_simulation(model.source, xpp_sim)
@@ -130,8 +118,9 @@ def exec_sed_task(task, variables, log=None):
     variable_results = get_results_of_sed_variables(sim, raw_results, variables)
 
     # log action
-    log.algorithm = exec_kisao_id
-    log.simulator_details = xpp_sim['simulation_method']
+    if config.LOG:
+        log.algorithm = exec_kisao_id
+        log.simulator_details = xpp_sim['simulation_method']
 
     ############################
     # return the result of each variable and log
